Deep GP and Deep Sigma Point Processes
========================================

Deep GP and Deep Sigma Point Processes are hierarchical models
where each layer is a Gaussian process.

Deep GP
----------

- `Standard Deep GP regression <./Deep_Gaussian_Processes.ipynb>`_
- `Multitask Deep GP regression <./DGP_Multitask_Regression.ipynb>`_

Deep Sigma Point Processes (DSPP)
---------------------------------------

- `DSPP regression <./Deep_Sigma_Point_Processes.ipynb>`_
- `Multitask DSPP regression <./DGP_Multitask_Regression.ipynb>`_

.. toctree::
   :glob:
   :maxdepth: 1
   :hidden:

   Deep_Gaussian_Processes.ipynb
   Deep_Sigma_Point_Processes.ipynb
   DGP_Multitask_Regression.ipynb
